R6 class object used for generating and storing plots and other processed data. It is accessed internally to display data. Each top level list contains a different type of plot. Sublists are organised to store different plot versions. Functions for plotting (i.e. plot_actogram, plot_DAct) get data from fct_R6_Custom_tables object and generate a plot that is saved into the relative list. There should be a method to pass plots to an external container based on the handler.
Public fields
storenamed list used as a keyed registry for all plot objects. Use store_obj(key, object) and retrieve_obj(key) to read and write. Keys used in the app: "ts_original", "ts_annotated", "periodogram_total", "periodogram_faceted", "periodogram_averaged", "period_barplot".
actTableTable containing data assembled using showData()
metaTableTable containing data assembled using showMeta() showMeta
Methods
Method showMeta()
function to create a table that arranges all the available metadata in a table, and saves it in metaTable var
Method showData()
function to create a table that arranges activity data in a table, and saves it in actTable var
Method plot_Timeserie()
a function to create Timeseries plots
Usage
Annotate$plot_Timeserie(
datatable,
value,
env,
tmin = 0,
tmax = 999.81,
data1 = TRUE,
data2 = FALSE,
data3 = FALSE,
timeformat = "Hours"
)Arguments
datatablelist contain all the data
valuestring to select data source: original, detrended or cleaned
envenvironment. App settings environment
tmindouble. minimum time to be plotted
tmaxdouble. maximum time to be plotted
data1Boolean. is dataset 1 present?
data2Boolean. is dataset 2 present?
data3Boolean. is dataset 3 present?
timeformatString. is the time in hours or posixt
Method plot_Timeserie_facet()
a function to create Timeseries plots stacked inside a grid
Usage
Annotate$plot_Timeserie_facet(
datalist,
value,
env,
tmin = 0,
tmax = 999.81,
data1 = TRUE,
data2 = FALSE,
data3 = FALSE,
timeformat = "Hours"
)Arguments
datalistlist contain all the data
valuestring to select data source: original, detrended or cleaned
envenvironment. App settings environment
tmindouble. minimum time to be plotted
tmaxdouble. maximum time to be plotted
data1Boolean. is dataset 1 present?
data2Boolean. is dataset 2 present?
data3Boolean. is dataset 3 present?
timeformatString. is the time in hours or posixt
Method plot_periodogram()
Function to generate periodogram plots
Usage
Annotate$plot_periodogram(
method,
plotType = c("Pertotal", "Perfaceted", "Peraveraged"),
FunEnv
)