Skip to contents

How to return values from each module to the main app logic: Inside each module 1. create a variable containing a NULL reactiveValue for each value to return toReturn = reactiveValues(example = NULL) 2. populate a mod_out list with all the reactiveValues created mod1_out <- list(example = toReturn$example) 3. return the mod1_out variable In the app_server.R fie 1. import the returned object, including the App_settings environment mod1_out <- mod_mod1_server("mod1_1", env = App_settings)

Details

TEMPLATE - to copy and paste in your module upon creation